HttpConfig class

http 配置信息

Constructors

HttpConfig(String baseUrl, IThrowHandler throwHandler, {Map<String, dynamic>? headers, String? cookiesPath, String? cachePath, bool showLog = true, int connectTimeout = 5000, int receiveTimeout = 5000, int sendTimeout = 5000})

Properties

baseUrl → String
final
cachePath → String?
final
connectTimeout → int
final
cookiesPath → String?
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, dynamic>?
final
receiveTimeout → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendTimeout → int
final
showLog → bool
final
throwHandler → IThrowHandler
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited