HttpPlatform class

http动态配置

Constructors

HttpPlatform()
工厂构造函数
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
throwHandler ↔ IThrowHandler?
getter/setter pair
token ↔ String?
登录token
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

get → HttpPlatform
提供静态获取方法
no setter