NumUtils class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

add(num a, num b) → Decimal
加 (精确相加,防止精度丢失).
addStr(String a, String b) → Decimal
两个数相加(防止精度丢失)
divide(num a, num b) → Rational
除 (精确相除,防止精度丢失).
divideStr(String a, String b) → Rational
除
isEqualStr(String a, String b) → bool
判断a是否等于b
isGreaterOrEqualStr(String a, String b) → bool
判断a是否大于等于b
isGreaterThanStr(String a, String b) → bool
判断a是否大于b
isLessOrEqualStr(String a, String b) → bool
判断a是否小于或者等于b
isLessThanStr(String a, String b) → bool
判断a是否小于b
multi(num a, num b) → Decimal
乘 (精确相乘,防止精度丢失).
multiStr(String a, String b) → Decimal
乘
remainder(num a, num b) → Decimal
余数
remainderStr(String a, String b) → Decimal
余数
sub(num a, num b) → Decimal
减 (精确相减,防止精度丢失).
subStr(String a, String b) → Decimal
减