SystemUtils class

系统工具类

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

clearClientKeyboard() → void
清除数据
copyToClipboard(String? text) → bool
拷贝文本内容到剪切板
hideKeyboard() → void
隐藏软键盘
showKeyboard() → void
展示软键盘