TextUtils class

文本工具类

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

formatDigitPattern(String text, {int digit = 4, String pattern = ' '}) → String
每隔 x位 加 pattern。比如用来格式化银行卡
formatDigitPatternEnd(String text, {int digit = 4, String pattern = ' '}) → String
每隔 x位 加 pattern, 从末尾开始
reverse(String? text) → String
反转字符串