XUtils class

Properties

hashCode → int
The hash code for this object.
no setterinherited
isDebug ↔ bool
是否为调试模式
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

init({bool? debug}) → Future<XUtils>
初始化
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

get → XUtils
提供静态获取方法
no setter